@@ -1,12 +1,13 @@
 package Yukki;
 BEGIN {
-  $Yukki::VERSION = '0.111660';
+  $Yukki::VERSION = '0.111720';
 }
 use 5.12.1;
 use Moose;
 
 use Yukki::Settings;
 use Yukki::Types qw( AccessLevel );
+use Yukki::Error qw( http_throw );
 
 use Crypt::SaltedHash;
 use MooseX::Params::Validate;
@@ -76,7 +77,7 @@ sub _locate {
 
     my $path_class = $type eq 'file' ? 'Path::Class::File'
                    : $type eq 'dir'  ? 'Path::Class::Dir'
-                   : Yukki::Error->throw("unkonwn location type $type");
+                   : http_throw("unkonwn location type $type");
 
     my $base_path = $self->settings->$base;
     if ($base_path !~ m{^/}) {
@@ -173,7 +174,7 @@ Yukki - Yet Uh-nother wiki
 
 =head1 VERSION
 
-version 0.111660
+version 0.111720
 
 =head1 DESCRIPTION
 
